@@ -76,6 +76,8 @@ class HTML2FOConverter(object):
 
         fo_text = fo_text.replace('<fo:block ' , '<fo:block margin-top="0" margin-bottom="0" ')  # avoid a linebreak through <li><p> (XFC)
         fo_text = fo_text.replace('<fo:block/>', '') # causes a crash with XINC    
+        fo_text = fo_text.replace('page-break-after="always"', 'break-after="page"')
+        
 
         # replace margin|padding-left|right|top-bottom="0" with ..="0em"
         def replacer(mo):
@@ -84,6 +86,8 @@ class HTML2FOConverter(object):
         reg = re.compile('(margin|padding)-(left|right|top|bottom)="0"', re.I|re.S|re.M)
         fo_text = reg.sub(replacer, fo_text)
 
+        print fo_filename
+
         open(fo_filename, 'wb').write(fo_text)
         return fo_filename
 
